==> scala-k8s-objects_native0.4_2.12-0.4.0-sources.jar: io/k8s/api/core/v1/ReplicationControllerStatus.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** ReplicationControllerStatus represents the current status of a replication controller. */
final case class ReplicationControllerStatus(
  replicas : Int,
  conditions : Option[Seq[io.k8s.api.core.v1.ReplicationControllerCondition]] = None,
  availableReplicas : Option[Int] = None,
  observedGeneration : Option[Int] = None,
  readyReplicas : Option[Int] = None,
  fullyLabeledReplicas : Option[Int] = None
) {

  /** Returns a new data with replicas set to new value */
  def withReplicas(value: Int) : ReplicationControllerStatus = copy(replicas = value)
  /** transforms replicas to result of function */
  def mapReplicas(f: Int => Int) : ReplicationControllerStatus = copy(replicas = f(replicas))

  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.api.core.v1.ReplicationControllerCondition]) : ReplicationControllerStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.api.core.v1.ReplicationControllerCondition*) : ReplicationControllerStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.api.core.v1.ReplicationControllerCondition] => Seq[io.k8s.api.core.v1.ReplicationControllerCondition]) : ReplicationControllerStatus = copy(conditions = conditions.map(f))

  /** Returns a new data with availableReplicas set to new value */
  def withAvailableReplicas(value: Int) : ReplicationControllerStatus = copy(availableReplicas = Some(value))
  /** if availableReplicas has a value, transforms to the result of function*/
  def mapAvailableReplicas(f: Int => Int) : ReplicationControllerStatus = copy(availableReplicas = availableReplicas.map(f))

  /** Returns a new data with observedGeneration set to new value */
  def withObservedGeneration(value: Int) : ReplicationControllerStatus = copy(observedGeneration = Some(value))
  /** if observedGeneration has a value, transforms to the result of function*/
  def mapObservedGeneration(f: Int => Int) : ReplicationControllerStatus = copy(observedGeneration = observedGeneration.map(f))

  /** Returns a new data with readyReplicas set to new value */
  def withReadyReplicas(value: Int) : ReplicationControllerStatus = copy(readyReplicas = Some(value))
  /** if readyReplicas has a value, transforms to the result of function*/
  def mapReadyReplicas(f: Int => Int) : ReplicationControllerStatus = copy(readyReplicas = readyReplicas.map(f))

  /** Returns a new data with fullyLabeledReplicas set to new value */
  def withFullyLabeledReplicas(value: Int) : ReplicationControllerStatus = copy(fullyLabeledReplicas = Some(value))
  /** if fullyLabeledReplicas has a value, transforms to the result of function*/
  def mapFullyLabeledReplicas(f: Int => Int) : ReplicationControllerStatus = copy(fullyLabeledReplicas = fullyLabeledReplicas.map(f))
}

object ReplicationControllerStatus {

    implicit val encoder : Encoder[io.k8s.api.core.v1.ReplicationControllerStatus] = new Encoder[io.k8s.api.core.v1.ReplicationControllerStatus] {
        def apply[T : Builder](o: io.k8s.api.core.v1.ReplicationControllerStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("replicas", o.replicas)
            .write("conditions", o.conditions)
            .write("availableReplicas", o.availableReplicas)
            .write("observedGeneration", o.observedGeneration)
            .write("readyReplicas", o.readyReplicas)
            .write("fullyLabeledReplicas", o.fullyLabeledReplicas)
            .build
        }
    }

    implicit val decoder: Decoder[ReplicationControllerStatus] = new Decoder[ReplicationControllerStatus] {
      def apply[T : Reader](t: T): Either[String, ReplicationControllerStatus] = for {
          obj <- ObjectReader(t)
          replicas <- obj.read[Int]("replicas")
          conditions <- obj.readOpt[Seq[io.k8s.api.core.v1.ReplicationControllerCondition]]("conditions")
          availableReplicas <- obj.readOpt[Int]("availableReplicas")
          observedGeneration <- obj.readOpt[Int]("observedGeneration")
          readyReplicas <- obj.readOpt[Int]("readyReplicas")
          fullyLabeledReplicas <- obj.readOpt[Int]("fullyLabeledReplicas")
      } yield ReplicationControllerStatus (
          replicas = replicas,
          conditions = conditions,
          availableReplicas = availableReplicas,
          observedGeneration = observedGeneration,
          readyReplicas = readyReplicas,
          fullyLabeledReplicas = fullyLabeledReplicas
        )
    }
}

==> scala-k8s-objects_native0.4_3-0.15.3-sources.jar: io/k8s/api/core/v1/ReplicationControllerStatus.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** ReplicationControllerStatus represents the current status of a replication controller. */
final case class ReplicationControllerStatus(
  replicas : Int,
  conditions : Option[Seq[io.k8s.api.core.v1.ReplicationControllerCondition]] = None,
  availableReplicas : Option[Int] = None,
  observedGeneration : Option[Long] = None,
  readyReplicas : Option[Int] = None,
  fullyLabeledReplicas : Option[Int] = None
) {

  /** Returns a new data with replicas set to new value */
  def withReplicas(value: Int) : ReplicationControllerStatus = copy(replicas = value)
  /** transforms replicas to result of function */
  def mapReplicas(f: Int => Int) : ReplicationControllerStatus = copy(replicas = f(replicas))

  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.api.core.v1.ReplicationControllerCondition]) : ReplicationControllerStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.api.core.v1.ReplicationControllerCondition*) : ReplicationControllerStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.api.core.v1.ReplicationControllerCondition] => Seq[io.k8s.api.core.v1.ReplicationControllerCondition]) : ReplicationControllerStatus = copy(conditions = conditions.map(f))

  /** Returns a new data with availableReplicas set to new value */
  def withAvailableReplicas(value: Int) : ReplicationControllerStatus = copy(availableReplicas = Some(value))
  /** if availableReplicas has a value, transforms to the result of function*/
  def mapAvailableReplicas(f: Int => Int) : ReplicationControllerStatus = copy(availableReplicas = availableReplicas.map(f))

  /** Returns a new data with observedGeneration set to new value */
  def withObservedGeneration(value: Long) : ReplicationControllerStatus = copy(observedGeneration = Some(value))
  /** if observedGeneration has a value, transforms to the result of function*/
  def mapObservedGeneration(f: Long => Long) : ReplicationControllerStatus = copy(observedGeneration = observedGeneration.map(f))

  /** Returns a new data with readyReplicas set to new value */
  def withReadyReplicas(value: Int) : ReplicationControllerStatus = copy(readyReplicas = Some(value))
  /** if readyReplicas has a value, transforms to the result of function*/
  def mapReadyReplicas(f: Int => Int) : ReplicationControllerStatus = copy(readyReplicas = readyReplicas.map(f))

  /** Returns a new data with fullyLabeledReplicas set to new value */
  def withFullyLabeledReplicas(value: Int) : ReplicationControllerStatus = copy(fullyLabeledReplicas = Some(value))
  /** if fullyLabeledReplicas has a value, transforms to the result of function*/
  def mapFullyLabeledReplicas(f: Int => Int) : ReplicationControllerStatus = copy(fullyLabeledReplicas = fullyLabeledReplicas.map(f))
}

object ReplicationControllerStatus {

    implicit val encoder : Encoder[io.k8s.api.core.v1.ReplicationControllerStatus] = new Encoder[io.k8s.api.core.v1.ReplicationControllerStatus] {
        def apply[T : Builder](o: io.k8s.api.core.v1.ReplicationControllerStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("replicas", o.replicas)
            .write("conditions", o.conditions)
            .write("availableReplicas", o.availableReplicas)
            .write("observedGeneration", o.observedGeneration)
            .write("readyReplicas", o.readyReplicas)
            .write("fullyLabeledReplicas", o.fullyLabeledReplicas)
            .build
        }
    }

    implicit val decoder: Decoder[ReplicationControllerStatus] = new Decoder[ReplicationControllerStatus] {
      def apply[T : Reader](t: T): Either[String, ReplicationControllerStatus] = for {
          obj <- ObjectReader(t)
          replicas <- obj.read[Int]("replicas")
          conditions <- obj.readOpt[Seq[io.k8s.api.core.v1.ReplicationControllerCondition]]("conditions")
          availableReplicas <- obj.readOpt[Int]("availableReplicas")
          observedGeneration <- obj.readOpt[Long]("observedGeneration")
          readyReplicas <- obj.readOpt[Int]("readyReplicas")
          fullyLabeledReplicas <- obj.readOpt[Int]("fullyLabeledReplicas")
      } yield ReplicationControllerStatus (
          replicas = replicas,
          conditions = conditions,
          availableReplicas = availableReplicas,
          observedGeneration = observedGeneration,
          readyReplicas = readyReplicas,
          fullyLabeledReplicas = fullyLabeledReplicas
        )
    }
}
